@@ -1,23 +1,23 @@
-import datetime
-
 from django.db import models
 from django.core.urlresolvers import reverse
+from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext as _
 
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import User
 
-from actstream import managers, settings as actstream_settings
-from actstream.signals import action
-from actstream.actions import action_handler
-
 try:
     from django.utils import timezone
     now = timezone.now
 except ImportError:
-    now = datetime.datetime.now
+    from datetime import datetime
+    now = datetime.now
 
+from actstream import settings as actstream_settings
+from actstream.signals import action
+from actstream.actions import action_handler
+from actstream.managers import FollowManager
 
 class Follow(models.Model):
     """
@@ -30,7 +30,8 @@ class Follow(models.Model):
     follow_object = generic.GenericForeignKey()
     actor_only = models.BooleanField("Only follow actions where the object is "
         "the target.", default=True)
-    objects = managers.FollowManager()
+    started = models.DateTimeField(default=now)
+    objects = FollowManager()
 
     class Meta:
         unique_together = ('user', 'content_type', 'object_id')
@@ -92,7 +93,7 @@ class Action(models.Model):
 
     public = models.BooleanField(default=True)
 
-    objects = actstream_settings.MANAGER_MODULE()
+    objects = actstream_settings.get_action_manager()
 
     class Meta:
         ordering = ('-timestamp', )
@@ -153,13 +154,14 @@ action_object_stream = Action.objects.action_object
 target_stream = Action.objects.target
 user_stream = Action.objects.user
 model_stream = Action.objects.model_actions
-
+followers = Follow.objects.followers
+following = Follow.objects.following
 
 def setup_generic_relations():
     """
     Set up GenericRelations for actionable models.
     """
-    for model in actstream_settings.MODELS.values():
+    for model in actstream_settings.get_models().values():
         if not model:
             continue
         for field in ('actor', 'target', 'action_object'):
@@ -177,5 +179,14 @@ def setup_generic_relations():
 
 setup_generic_relations()
 
+
+if actstream_settings.USE_JSONFIELD:
+    try:
+        from jsonfield.fields import JSONField
+    except ImportError:
+        raise ImproperlyConfigured('You must have django-extensions installed '
+                                'if you wish to use a JSONField on your actions')
+    JSONField(blank=True, null=True).contribute_to_class(Action, 'data')
+
 # connect the signal
 action.connect(action_handler, dispatch_uid='actstream.models')
