@@ -10,11 +10,11 @@ from django.contrib.sites.models import Site
 from django.template.loader import Template, Context
 
 from actstream.models import Action, Follow, model_stream, user_stream,\
-    setup_generic_relations
+    setup_generic_relations, following, followers
 from actstream.actions import follow, unfollow
 from actstream.exceptions import ModelNotActionable
 from actstream.signals import action
-from actstream import settings as actstream_settings
+from actstream.settings import get_models, SETTINGS
 
 class LTE(int):
     def __new__(cls, n):
@@ -32,15 +32,14 @@ class ActivityBaseTestCase(TestCase):
     actstream_models = ()
 
     def setUp(self):
-        self.old_MODELS = actstream_settings.MODELS
-        actstream_settings.MODELS = {}
+        self.old_models = get_models()
+        SETTINGS['MODELS'] = {}
         for model in self.actstream_models:
-            actstream_settings.MODELS[model.lower()] = \
-                get_model(*model.split('.'))
+            SETTINGS['MODELS'][model.lower()] = get_model(*model.split('.'))
         setup_generic_relations()
 
     def tearDown(self):
-        actstream_settings.MODELS = self.old_MODELS
+        SETTINGS['MODELS'] = self.old_models
 
 
 class ActivityTestCase(ActivityBaseTestCase):
@@ -96,6 +95,13 @@ class ActivityTestCase(ActivityBaseTestCase):
         self.assertEqual(map(unicode, Action.objects.actor(self.group)),
             [u'CoolGroup responded to admin: Sweet Group!... 0 minutes ago'])
 
+    def test_following(self):
+        self.assertEqual(list(following(self.user1)), [self.user2])
+        self.assertEqual(len(following(self.user2, User)), 0)
+
+    def test_followers(self):
+        self.assertEqual(list(followers(self.group)), [self.user2])
+
     def test_empty_follow_stream(self):
         unfollow(self.user1, self.user2)
         self.assert_(not user_stream(self.user1))
@@ -163,10 +169,15 @@ class ActivityTestCase(ActivityBaseTestCase):
         self.assertEquals(f1, f2, "Should have received the same Follow "
             "object that I first submitted")
 
-    def test_zzzz_no_orphaned_actions(self):
+    def test_y_no_orphaned_follows(self):
+        follows = Follow.objects.count()
+        self.user2.delete()
+        self.assertEqual(follows - 1, Follow.objects.count())
+
+    def test_z_no_orphaned_actions(self):
         actions = self.user1.actor_actions.count()
         self.user2.delete()
-        self.assertEqual(actions, self.user1.actor_actions.count() + 1)
+        self.assertEqual(actions - 1, self.user1.actor_actions.count())
 
     def test_generic_relation_accessors(self):
         self.assertEqual(self.user2.actor_actions.count(), 2)
@@ -189,28 +200,6 @@ class ActivityTestCase(ActivityBaseTestCase):
         ct = ContentType.objects.get_for_model(User)
         self.assertEqual(output, '/follow/%s/%s/' % (ct.pk, self.user1.pk))
 
-    def test_tag_follow_label(self):
-        src = '{% load activity_tags %}'\
-            '{% follow_label other_user yup nope %}'
-
-        # Anonymous.
-        output = Template(src).render(Context({'other_user': self.user1}))
-        self.assertEqual(output, 'nope')
-
-        output = Template(src).render(Context({'user': AnonymousUser(),
-            'other_user': self.user1}))
-        self.assertEqual(output, 'nope')
-
-        # Non follower (user2 does not follow user1).
-        output = Template(src).render(Context({'user': self.user2,
-            'other_user': self.user1}))
-        self.assertEqual(output, 'nope')
-
-        # Follower (user1 follows user2).
-        output = Template(src).render(Context({'user': self.user1,
-            'other_user': self.user2}))
-        self.assertEqual(output, 'yup')
-
     def test_model_actions_with_kwargs(self):
         """
         Testing the model_actions method of the ActionManager
